.. :changelog:

History
-------

0.1.0 (2015-09-23)
---------------------

* created basic market data sourcing from Yahoo! and CNBC

0.2.0 (2016-11-22)
------------------

* created S&P500 stock listing scraper
* implemented TA-lib for technical analysis (ADX, DI, STOCH)
* added zipline bundles to data sourcing
* created zipline trading algorithms for trending and oscillating instruments
